Skip to contents

The model from Alroy 2014. Estimates a posterior probability that the species is extant at the end of the observation period.

Usage

AL14B1(records)

Arguments

records

sighting records in cbin format (see convert_dodo for details).

Value

a list object with the original parameters and p(extant) included as elements.

Note

All sighting records are assumed to be certain and sampling effort is assumed to be constant.

References

Key Reference

Alroy, J. (2014). A simple Bayesian method of inferring extinction. Paleobiology, 40(4), 584-607. doi:10.1666/13074

Other References

Alroy, J. (2016). On a conservative Bayesian method of inferring extinction. Paleobiology, 42(4), 670-679. doi:10.1017/pab.2016.12

Alroy, J. (2016). A simple Bayesian method of inferring extinction: reply. Ecology, 97(3), 798-800. doi:10.1002/ecy.1321

See also

Examples

# Run an example analysis using the Caribbean Monk Seal data
AL14B1(as.integer(1915:1992 %in% monk_seal))
#> $records
#>  [1] 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1
#> [39] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
#> [77] 0 0
#> 
#> $p.extant
#> [1] 1.417755e-13
#> 
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
AL14B1(curlew$cbin)
} # }