Skip to contents

Equation 4 from Burgman et al. 1995. Estimates a p-value for testing competing hypotheses of extinction/non-extinction.

Usage

BU95F3(records)

Arguments

records

sighting records in cdis format (see convert_dodo for details).

Value

a list object with the original parameters and the p-value included as elements.

Note

All sighting records are assumed to be certain and sampling effort is assumed to be constant.

Adapts code from the sExtinct package (GitHub)

References

Key Reference

Burgman, M. A., Grimson, R. C., & Ferson, S. (1995). Inferring Threat from Scientific Collections. Conservation Biology, 9(4), 923-928. doi:0.1046/j.1523-1739.1995.09040923.x

Other References

Clements, C. F., Collen, B., Blackburn, T. M., & Petchey, O. L. (2014). Effects of recent environmental change on accuracy of inferences of extinction status. Conservation Biology, 28(4), 971-981. doi:10.1111/cobi.12329

Grimson, R. C., Aldrich, T. E., & Drane, J. W. (1992). Clustering in sparse data and an analysis of rhabdomyosarcoma incidence. Statistics in Medicine, 11(6), 761-768. doi:10.1002/sim.4780110607

See also

Examples

# Run the example analysis from Burgman 1995 (Figure 1b)
BU95F3(burgman_figure1b)
#> $records
#>  [1] 1 2 0 2 0 3 2 0 0 0 0 0 0 0 0 0
#> 
#> $p.value
#> [1] 0.001670322
#> 
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
BU95F3(curlew$cdis)
} # }