Skip to contents

Constant population model from Caley & Barry 2014. Estimates a posterior probability that the species is extant at the test time, and a point estimate and one-sided \(1 - \alpha\) credible interval on the time of extinction.

Usage

CB14B1(
  records,
  alpha = 0.05,
  init.time,
  test.time = init.time + length(records) - 1,
  n.iter = 1e+05
)

Arguments

records

sighting records in cbin format (see convert_dodo for details).

alpha

desired threshold level (defaults to \(\alpha = 0.05\)) of the \(1 - \alpha\) credible interval.

init.time

start of the observation period.

test.time

time point to retrospectively calculate extinction probability at. Defaults to the end of the observation period.

n.iter

number of iterations to run (defaults to 100,000).

Value

a list object with the original parameters and the p(extant), point estimate, and credible interval included as elements. The credible interval is a two-element numeric vector called cred.int.

Note

All sighting records are assumed to be certain and sampling effort is assumed to be constant.

References

Key Reference

Caley, P., & Barry, S. C. (2014). Quantifying extinction probabilities from sighting records: inference and uncertainties. PLoS One, 9(4), e95857. doi:10.1371/journal.pone.0095857

See also

Examples

# Run the fox analysis from Caley & Barry 2014
CB14B1(fox, init.time = 2001, test.time = 2012)
#> $records
#>  [1] 1 0 1 0 1 1 0 0 0 0 0 0
#> 
#> $alpha
#> [1] 0.05
#> 
#> $init.time
#> [1] 2001
#> 
#> $test.time
#> [1] 2012
#> 
#> $n.iter
#> [1] 1e+05
#> 
#> $p.extant
#> [1] 0.06168
#> 
#> $estimate
#> [1] 2007
#> 
#> $cred.int
#> [1] 2007 2015
#> 
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
CB14B1(curlew$cbin, init.time = 1817)
} # }