Skip to contents

Model 1 from Kodikara et al. 2020. Estimates a posterior probability that the species is extant at the test time, and a point estimate and one-sided \(1 - \alpha\) credible interval on the time of extinction.

Usage

KO20B1(
  records,
  alpha = 0.05,
  init.time,
  test.time = init.time + length(records) - 1,
  n.chains = 4,
  n.iter = 110000,
  n.burnin = 10000,
  n.thin = 10
)

Arguments

records

sighting records in cbin format (see convert_dodo for details).

alpha

desired threshold level (defaults to \(\alpha = 0.05\)) of the \(1 - \alpha\) credible interval.

init.time

start of the observation period.

test.time

time point to retrospectively calculate extinction probability at. Defaults to the end of the observation period.

n.chains

number of MCMC chains to run. Defaults to 4.

n.iter

number of iterations in each chain. Defaults to 110,000.

n.burnin

number of iterations to discard as burn-in. Defaults to 10,000.

n.thin

thinning rate. Defaults to 10.

Value

a list object with the original parameters and the p(extant), point estimate, and credible interval included as elements. The credible interval is a two-element numeric vector called cred.int.

Note

All sighting records are assumed to be certain and sampling effort is assumed to be constant.

References

Key Reference

Kodikara, S., Demirhan, H., Wang, Y., Solow, A., & Stone, L. (2020). Inferring extinction year using a Bayesian approach. Methods in Ecology and Evolution, 11(8), 964-973. doi:10.1111/2041-210x.13408

See also

Examples

if (FALSE) { # \dontrun{
# Run the Ivory-billed Woodpecker analysis from Kodikara et al. 2020
KO20B1(woodpecker$cbin, init.time = 1897, test.time = 2010)
# Run an example analysis using the Slender-billed Curlew data
KO20B1(curlew$cbin, init.time = 1817, test.time = 2022)
} # }