Solow & Beet's (2014) "Model 2" model
SB14B2.RdThe second model from Solow & Beet 2014. Estimates a Bayes factor comparing competing hypotheses of extinction / persistence.
Arguments
- records
sighting records in
ubinformat (seeconvert_dodofor details).- init.time
start of the observation period.
- increment
step size used for integration. Defaults to 0.01, following the original code from Solow & Beet 2014.
References
Key Reference
Solow, A. R., & Beet, A. R. (2014). On uncertain sightings and inference about extinction. Conservation Biology, 28(4), 1119-1123. doi:10.1111/cobi.12309
Other References
Solow, A., Smith, W., Burgman, M., Rout, T., Wintle, B., & Roberts, D. (2012). Uncertain sightings and the extinction of the Ivory-billed Woodpecker. Conservation Biology, 26(1), 180-184. doi:10.1111/j.1523-1739.2011.01743.x
Carlson, C. J., Bond, A. L., & Burgio, K. R. (2018). Estimating the extinction date of the thylacine with mixed certainty data. Conservation Biology, 32(2), 477-483. doi:10.1111/cobi.13037
Carlson, C. J., Burgio, K. R., Dallas, T. A., & Bond, A. L. (2018). Spatial extinction date estimation: a novel method for reconstructing spatiotemporal patterns of extinction and identifying potential zones of rediscovery. bioRxiv preprint. doi:10.1101/279679
Kodikara, S., Demirhan, H., & Stone, L. (2018). Inferring about the extinction of a species using certain and uncertain sightings. Journal of Theoretical Biology, 442, 98-109. doi:10.1016/j.jtbi.2018.01.015
Burgio, K. R., Carlson, C. J., Bond, A. L., Rubega, M. A., & Tingley, M. W. (2021). The two extinctions of the Carolina Parakeet Conuropsis carolinensis. Bird Conservation International, 1-8. doi:10.1017/s0959270921000241
Examples
# Run the Ivory-billed Woodpecker analysis from Solow & Beet 2014
SB14B2(records = woodpecker$ubin, init.time = 1897, increment = 0.01)
#> $records
#> certain uncertain
#> 1 1 0
#> 2 1 0
#> 3 1 0
#> 4 1 0
#> 5 1 0
#> 6 1 0
#> 7 0 0
#> 8 1 0
#> 9 1 0
#> 10 1 0
#> 11 1 0
#> 12 1 0
#> 13 1 0
#> 14 1 0
#> 15 0 1
#> 16 0 0
#> 17 1 0
#> 18 1 0
#> 19 0 0
#> 20 0 1
#> 21 1 0
#> 22 0 0
#> 23 0 0
#> 24 0 1
#> 25 0 1
#> 26 0 0
#> 27 0 1
#> 28 1 0
#> 29 1 0
#> 30 0 1
#> 31 0 0
#> 32 0 0
#> 33 0 1
#> 34 0 1
#> 35 0 1
#> 36 1 0
#> 37 0 1
#> 38 0 1
#> 39 1 0
#> 40 0 1
#> 41 0 1
#> 42 1 0
#> 43 1 0
#> 44 0 0
#> 45 0 1
#> 46 0 1
#> 47 0 1
#> 48 0 1
#> 49 0 0
#> 50 0 1
#> 51 0 0
#> 52 0 1
#> 53 0 1
#> 54 0 1
#> 55 0 1
#> 56 0 1
#> 57 0 0
#> 58 0 0
#> 59 0 1
#> 60 0 0
#> 61 0 0
#> 62 0 1
#> 63 0 1
#> 64 0 0
#> 65 0 0
#> 66 0 1
#> 67 0 0
#> 68 0 0
#> 69 0 0
#> 70 0 1
#> 71 0 1
#> 72 0 1
#> 73 0 1
#> 74 0 0
#> 75 0 1
#> 76 0 1
#> 77 0 1
#> 78 0 1
#> 79 0 0
#> 80 0 1
#> 81 0 0
#> 82 0 0
#> 83 0 0
#> 84 0 0
#> 85 0 1
#> 86 0 1
#> 87 0 0
#> 88 0 0
#> 89 0 1
#> 90 0 1
#> 91 0 1
#> 92 0 1
#> 93 0 0
#> 94 0 0
#> 95 0 0
#> 96 0 0
#> 97 0 0
#> 98 0 0
#> 99 0 0
#> 100 0 0
#> 101 0 0
#> 102 0 0
#> 103 0 1
#> 104 0 0
#> 105 0 0
#> 106 0 0
#> 107 0 0
#> 108 0 1
#> 109 0 1
#> 110 0 1
#> 111 0 0
#> 112 0 0
#> 113 0 0
#> 114 0 0
#>
#> $init.time
#> [1] 1897
#>
#> $increment
#> [1] 0.01
#>
#> $Bayes.factor
#> [1] 4192799
#>
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
SB14B2(curlew$ubin, init.time = 1817, increment = 0.01)
} # }