Skip to contents

Equations 8 and 20 from Strauss & Sadler 1989. Estimates a one-sided \(1 - \alpha\) confidence interval and point estimate on the time of extinction.

Usage

SS89F1(records, alpha = 0.05)

Arguments

records

sighting records in ccon format (see convert_dodo for details).

alpha

desired significance level (defaults to \(\alpha = 0.05\)) of the \(1 - \alpha\) confidence interval.

Value

a list object with the original parameters and the point estimate and confidence interval included as elements. The confidence interval is a two-element numeric vector called conf.int.

Note

All sighting records are assumed to be certain and sampling effort is assumed to be constant.

References

Key Reference

Strauss, D., & Sadler, P. M. (1989). Classical Confidence Intervals and Bayesian Probability Estimates for Ends of Local Taxon Ranges. Mathematical Geology, 21(4), 411-421. doi:10.1007/Bf00897326

Other References

Marshall, C. R. (1990). Confidence intervals on stratigraphic ranges. Paleobiology, 16(1), 1-10. doi:10.1017/S0094837300009672

McFarlane, D. A. (1999). A Comparison of Methods for the Probabilistic Determination of Vertebrate Extinction Chronologies. In R. D. E. MacPhee (Ed.), Extinctions in Near Time (pp. 95-103). Springer US. doi:10.1007/978-1-4757-5202-1_5

Rivadeneira, M. M., Hunt, G., & Roy, K. (2009). The use of sighting records to infer species extinctions: an evaluation of different methods. Ecology, 90(5), 1291-1300. doi:10.1890/08-0316.1

See also

Examples

# Run an example analysis using the Caribbean Monk Seal data
SS89F1(monk_seal)
#> $records
#> [1] 1915 1922 1932 1948 1952
#> 
#> $alpha
#> [1] 0.05
#> 
#> $estimate
#> [1] 1961.25
#> 
#> $conf.int
#> [1] 1952.000 1993.245
#> 
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
SS89F1(curlew$ccon)
} # }