Alroy's (2014) "Creeping Shadow of a Doubt" model
AL14B1.RdThe model from Alroy 2014. Estimates a posterior probability that the species is extant at the end of the observation period.
Arguments
- records
sighting records in
cbinformat (seeconvert_dodofor details).
References
Key Reference
Alroy, J. (2014). A simple Bayesian method of inferring extinction. Paleobiology, 40(4), 584-607. doi:10.1666/13074
Other References
Alroy, J. (2016). On a conservative Bayesian method of inferring extinction. Paleobiology, 42(4), 670-679. doi:10.1017/pab.2016.12
Alroy, J. (2016). A simple Bayesian method of inferring extinction: reply. Ecology, 97(3), 798-800. doi:10.1002/ecy.1321
Examples
# Run an example analysis using the Caribbean Monk Seal data
AL14B1(as.integer(1915:1992 %in% monk_seal))
#> $records
#> [1] 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1
#> [39] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
#> [77] 0 0
#>
#> $p.extant
#> [1] 1.417755e-13
#>
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
AL14B1(curlew$cbin)
} # }