Caley & Barry's (2014) "Non-constant" model
CB14B2.RdNon-constant population model from Caley & Barry 2014. Estimates a posterior probability that the species is extant at the test time, and a point estimate and one-sided \(1 - \alpha\) credible interval on the time of extinction.
Usage
CB14B2(
records,
alpha = 0.05,
init.time = min(records),
test.time = as.numeric(format(Sys.Date(), "%Y")),
burn.in = 10000,
n.iter = 110000
)Arguments
- records
sighting records in
cbinformat (seeconvert_dodofor details).- alpha
desired threshold level (defaults to \(\alpha = 0.05\)) of the \(1 - \alpha\) credible interval.
- init.time
start of the observation period.
- test.time
time point to retrospectively calculate extinction probability at. Defaults to the end of the observation period.
- burn.in
number of initial iterations to discard as burn-in (defaults to 10,000).
- n.iter
number of iterations to run (defaults to 110,000).
Value
a list object with the original parameters and the p(extant),
point estimate, and credible interval included as elements. The credible
interval is a two-element numeric vector called cred.int.
References
Key Reference
Caley, P., & Barry, S. C. (2014). Quantifying extinction probabilities from sighting records: inference and uncertainties. PLoS One, 9(4), e95857. doi:10.1371/journal.pone.0095857
Examples
# Run the fox analysis from Caley & Barry 2014
CB14B2(fox, init.time = 2001, test.time = 2012, n.iter = 11e4, burn.in = 1e4)
#> $records
#> [1] 1 0 1 0 1 1 0 0 0 0 0 0
#>
#> $alpha
#> [1] 0.05
#>
#> $init.time
#> [1] 2001
#>
#> $test.time
#> [1] 2012
#>
#> $burn.in
#> [1] 10000
#>
#> $n.iter
#> [1] 110000
#>
#> $p.extant
#> [1] 0.29412
#>
#> $estimate
#> [1] 2009
#>
#> $cred.int
#> [1] 2007 Inf
#>
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
CB14B2(curlew$cbin, init.time = 1817, n.iter = 11e3, burn.in = 1e3)
} # }