McFarlane's (1999) "Median Gap" model
MC99F1.RdEquation 3 from McFarlane 1999. Estimates a p-value for testing competing hypotheses of extinction/non-extinction, and a one-sided \(1 - \alpha\) confidence interval on the time of extinction.
Usage
MC99F1(
records,
alpha = 0.05,
test.time = as.numeric(format(Sys.Date(), "%Y"))
)Arguments
- records
sighting records in
cconformat (seeconvert_dodofor details).- alpha
desired significance level (defaults to \(\alpha = 0.05\)) of the \(1 - \alpha\) confidence interval.
- test.time
end of the observation period, typically the present day (defaults to the current year).
Value
a list object with the original parameters and the p-value and
confidence interval included as elements. The confidence interval is
a two-element numeric vector called conf.int.
References
Key Reference
McFarlane, D. A. (1999). A Comparison of Methods for the Probabilistic Determination of Vertebrate Extinction Chronologies. In R. D. E. MacPhee (Ed.), Extinctions in Near Time (pp. 95-103). Springer US. doi:10.1007/978-1-4757-5202-1_5
Examples
# Run an example analysis using the Woolly Mammoth data
MC99F1(mammoth, test.time = -11000)
#> $records
#> [1] -14090 -14020 -13690 -13660 -13440 -13410 -13380 -13340 -13290 -13230
#> [11] -13060 -12880 -12680 -12580 -12510 -12490 -12480 -12440 -12430 -12340
#> [21] -12190 -12120 -11910 -11540 -11500
#>
#> $alpha
#> [1] 0.05
#>
#> $p.value
#> [1] 0.007075966
#>
#> $conf.int
#> [1] -11500.00 -11197.47
#>
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
MC99F1(curlew$ccon, test.time = 2022)
} # }