Springer & Lilje's (1988) "Broken Stick" model
SL88F1.RdEquation 3 from Springer & Lilje 1988. Estimates a one-sided \(1 - \alpha\) confidence interval on the time of extinction.
Arguments
- records
sighting records in
cconformat (seeconvert_dodofor details).- alpha
desired significance level (defaults to \(\alpha = 0.05\)) of the \(1 - \alpha\) confidence interval.
Value
a list object with the original parameters and the confidence
interval included as elements. The confidence interval is a two-element
numeric vector called conf.int.
References
Key Reference
Springer, M., & Lilje, A. (1988). Biostratigraphy and Gap Analysis - the Expected Sequence of Biostratigraphic Events. Journal of Geology, 96(2), 228-236. doi:10.1086/629212
Other References
McFarlane, D. A. (1999). A Comparison of Methods for the Probabilistic Determination of Vertebrate Extinction Chronologies. In R. D. E. MacPhee (Ed.), Extinctions in Near Time (pp. 95-103). Springer US. doi:10.1007/978-1-4757-5202-1_5
Strauss, D., & Sadler, P. M. (1989). Classical Confidence Intervals and Bayesian Probability Estimates for Ends of Local Taxon Ranges. Mathematical Geology, 21(4), 411-421. doi:10.1007/Bf00897326
Examples
# Run an example analysis using the Caribbean Monk Seal data
SL88F1(monk_seal)
#> $records
#> [1] 1915 1922 1932 1948 1952
#>
#> $alpha
#> [1] 0.05
#>
#> $conf.int
#> [1] 1952.000 1979.711
#>
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
SL88F1(curlew$ccon)
} # }