Thompson et al.'s (2013) "Deterministic" model
TH13B1.RdThe deterministic variant (\(P_D(X_T|\bm{s})\)) of Equation 9 in Thompson et al. 2013. Estimates a posterior probability that the species is extant at the end of the observation period.
Usage
TH13B1(records, priors, certain = c(1), PXT = NULL, PE = NULL)Arguments
- records
sighting records in
umcbformat (seeconvert_dodofor details).- priors
nested
listwith two elements:pandq, each of which is alistwith the same number of elements as there are sighting classes. For this deterministic model, each element is the point prior for the rate \(p_i^\alpha\) or \(q_i^\alpha\).- certain
which sighting types are considered certain. Defaults to
c(1)(i.e. only the first sighting class is certain).- PXT
estimate of \(P(X_T)\). Defaults to
NULL, in which case \(P(X_T) = TN / T\).- PE
estimate of \(P_E\). Defaults to
NULL, in which case \(P_E = 1 / T\).
References
Key Reference
Thompson, C. J., Lee, T. E., Stone, L., McCarthy, M. A., & Burgman, M. A. (2013). Inferring extinction risks from sighting records. Journal of Theoretical Biology, 338, 16-22. doi:10.1016/j.jtbi.2013.08.023
Examples
# Run the example analysis from Thompson et al. 2013 (Table 1 etc.)
TH13B1(
records = thompson_table1,
priors = list(
p = list(p1 = 0.30, p2 = 0.50, p3 = 0.45),
q = list(q1 = 1.00, q2 = 0.45, q3 = 0.30)
),
certain = c(1)
)
#> $records
#> time class_1 class_2 class_3
#> 1 1 1 1 0
#> 2 2 0 0 1
#> 3 3 1 0 1
#> 4 4 0 1 0
#> 5 5 0 0 0
#> 6 6 0 1 0
#> 7 7 0 0 1
#>
#> $priors
#> $priors$p
#> $priors$p$p1
#> [1] 0.3
#>
#> $priors$p$p2
#> [1] 0.5
#>
#> $priors$p$p3
#> [1] 0.45
#>
#>
#> $priors$q
#> $priors$q$q1
#> [1] 1
#>
#> $priors$q$q2
#> [1] 0.45
#>
#> $priors$q$q3
#> [1] 0.3
#>
#>
#>
#> $certain
#> [1] 1
#>
#> $p.extant
#> [1] 0.03729126
#>
if (FALSE) { # \dontrun{
# Run an example analysis using the Slender-billed Curlew data
TH13B1(
records = curlew$umcb,
priors = list(
p = list(p1 = 0.5, p2 = 0.5, p3 = 0.5, p4 = 0.5, p5 = 0.5, p6 = 0.5),
q = list(q1 = 1.0, q2 = 1.0, q3 = 0.5, q4 = 0.5, q5 = 0.5, q6 = 0.5)
),
certain = c(1, 2)
)
} # }